@@ -11,6 +11,7 @@ OC.L10N.register(
     "Description:" : "Descripcion :",
     "Date:" : "Data :",
     "Where:" : "Ont :",
+    "Location:" : "Localizacion :",
     "A Calendar app for Nextcloud" : "Una aplicacion de calendièr per Nextcloud",
     "Previous day" : "Jorn passat",
     "Previous week" : "Setmana passada",
@@ -40,19 +41,21 @@ OC.L10N.register(
     "Deleted" : "Suprimit",
     "Restore" : "Restaurar",
     "Delete permanently" : "Suprimir definitivament",
-    "Hidden" : "Amagat",
+    "Internal link" : "Ligam intèrn",
+    "Copy internal link" : "Copiar lo ligam intèrn",
     "Share link" : "Partejar lo ligam",
     "Copy public link" : "Copiar lo ligam public",
     "Copied code" : "Còdi copiat",
     "Could not copy code" : "Se poguèt pas copiar lo còdi",
     "Delete share link" : "Suprimir lo ligam de partatge",
     "Deleting share link …" : "Supression del ligam de partatge …",
-    "can edit" : "pòt modificar",
     "Save" : "Salvar",
+    "View" : "Veire",
     "Import calendars" : "Importar de calendièrs",
     "Filename" : "Nom de fichièr",
     "Cancel" : "Anullar",
     "_Import calendar_::_Import calendars_" : ["Importar un calendièr","Importar de calendièrs"],
+    "Attachments folder" : "Dossièr de pèças-juntas",
     "Automatic" : "Automatic",
     "Navigation" : "Navegacion",
     "Views" : "Vistas",
@@ -61,7 +64,9 @@ OC.L10N.register(
     "Month view" : "Monstrar un mes",
     "Actions" : "Accions",
     "or" : "o",
-    "Show weekends" : "Monstrar las dimenjadas",
+    "General" : "Generals",
+    "Editing" : "Edicion",
+    "Keyboard shortcuts" : "Acorchis de clavièr",
     "0 minutes" : "0 minuta",
     "Update" : "Metre a jorn",
     "Location" : "Emplaçament",
@@ -126,6 +131,11 @@ OC.L10N.register(
     "unavailable" : "indisponible",
     "Room type" : "Tipe de sala",
     "Any" : "Quina que siá",
+    "Remove participant" : "Tirar participant",
+    "Yes" : "Òc",
+    "No" : "Non",
+    "None" : "Cap",
+    "Create" : "Crear",
     "from {formattedDate}" : "a partir de {formattedDate}",
     "to {formattedDate}" : "cap a {formattedDate}",
     "Pick a time" : "Causir una ora",
@@ -138,6 +148,11 @@ OC.L10N.register(
     "All day" : "Tota la jornada",
     "Untitled event" : "Eveniment sens nom",
     "Close" : "Tampar",
+    "Selected" : "Seleccionat",
+    "Title" : "Títol",
+    "30 min" : "30 min",
+    "Participants" : "Participants",
+    "Submit" : "Transmetre",
     "Anniversary" : "Anniversari",
     "Appointment" : "Rendetz-vos",
     "Business" : "Afar",
@@ -170,10 +185,8 @@ OC.L10N.register(
     "Custom color" : "Color personalizada",
     "Error while sharing file" : "Error pendent lo partiment del fichièr",
     "User not found" : "Utilizaire pas trobat",
-    "Create a new conversation" : "Crear una conversacion novèla",
-    "Reminder" : "Recòrd",
-    "+ Add reminder" : "+ Apondre un rapèl",
-    "Suggestions" : "Suggestions",
-    "Details" : "Detalhs"
+    "Hidden" : "Amagat",
+    "can edit" : "pòt modificar",
+    "Show weekends" : "Monstrar las dimenjadas"
 },
 "nplurals=2; plural=(n > 1);");
